@@ -1,4 +1,5 @@
-package CheckSubCalled;
+package
+   CheckSubCalled;
 
 use strict;
 use warnings;
@@ -16,4 +17,4 @@ sub test2 {
     ok( with_ampersand() );
 }
 
-1;
\ No newline at end of file
+1;
